//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sample/HardParticle/FormFactorTruncatedSphere.h
//! @brief     Defines class FormFactorTruncatedSphere.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_SAMPLE_HARDPARTICLE_FORMFACTORTRUNCATEDSPHERE_H
#define BORNAGAIN_SAMPLE_HARDPARTICLE_FORMFACTORTRUNCATEDSPHERE_H

#include "Sample/Particle/IBornFF.h"

//! A truncated Sphere.
//! @ingroup hardParticle

class FormFactorTruncatedSphere : public IBornFF {
public:
    std::string className() const final { return "FormFactorTruncatedSphere"; }

    FormFactorTruncatedSphere(std::vector<double> P);
    FormFactorTruncatedSphere(double radius, double height, double dh);

    FormFactorTruncatedSphere* clone() const override
    {
        return new FormFactorTruncatedSphere(m_radius, m_height, m_dh);
    }

    double height() const { return m_height; }
    double radius() const { return m_radius; }
    double removedTop() const { return m_dh; }

    double radialExtension() const override { return m_radius; }

    complex_t formfactor(C3 q) const override;

private:
    const double& m_radius;
    const double& m_height;
    const double& m_dh;
};

#endif // BORNAGAIN_SAMPLE_HARDPARTICLE_FORMFACTORTRUNCATEDSPHERE_H
